==> fltk-docs-1.3.3-6-aarch64.pkg.tar.xz: usr/share/doc/fltk/classFl__Menu__.js <==
var classFl__Menu__ =
[
    [ "Fl_Menu_", "classFl__Menu__.html#aacd1de7901a51192b721bb5b7263f762", null ],
    [ "~Fl_Menu_", "classFl__Menu__.html#a4bbee6469b549cae405dae0f647397a3", null ],
    [ "add", "classFl__Menu__.html#ac380c9009765c4288577f01af9a3e4d5", null ],
    [ "add", "classFl__Menu__.html#aa4522277d81f2b6318136ea0020c20d4", null ],
    [ "add", "classFl__Menu__.html#a67b693829c184e98bb9b9cd0eb165a84", null ],
    [ "clear", "classFl__Menu__.html#a0e96567cab88c6b60e0be3dfcda00a99", null ],
    [ "clear_submenu", "classFl__Menu__.html#a9f5d44f76658dc88431e4c5e53a2aaf5", null ],
    [ "copy", "classFl__Menu__.html#a946f4bc95480ea9fe8113ddf6ae67c0d", null ],
    [ "down_box", "classFl__Menu__.html#ab3a61424c9ecca3dce9b3e40e38e43b0", null ],
    [ "down_box", "classFl__Menu__.html#a76c3794608213f1bb1d01f677a88d239", null ],
    [ "down_color", "classFl__Menu__.html#a4f9308eb72c1cfbd7a27bc5907ee6a6a", null ],
    [ "down_color", "classFl__Menu__.html#a17fa5c0577f05569787d6cd469d0d900", null ],
    [ "find_index", "classFl__Menu__.html#a07d9d33f649740d54610149091b9945d", null ],
    [ "find_index", "classFl__Menu__.html#af6f2656e6731299106f52b75a3cce00d", null ],
    [ "find_index", "classFl__Menu__.html#ab75df41c3b59dd45438db881b2ab8dbf", null ],
    [ "find_item", "classFl__Menu__.html#a83e66d9b948df288e9f36d812093e922", null ],
    [ "find_item", "classFl__Menu__.html#adc7c427163be5120501b6d54c259a251", null ],
    [ "global", "classFl__Menu__.html#aea0c7fce644de6b8703a6d8fff1941c0", null ],
    [ "insert", "classFl__Menu__.html#a4a6d21b279e679a93b13eee2534f9f64", null ],
    [ "insert", "classFl__Menu__.html#a799f709782364cd096b07fa6f14382b5", null ],
    [ "item_pathname", "classFl__Menu__.html#a4cbdd6e7fd291711b94d96aa7b7d1300", null ],
    [ "menu", "classFl__Menu__.html#a44b0dd7371022c6df07fda0e9aa0e293", null ],
    [ "menu", "classFl__Menu__.html#aa0708c71ee8422bf3e92b8fa471eda9f", null ],
    [ "mode", "classFl__Menu__.html#a1093ab1105fc5ecbaf9ae702c21ecf36", null ],
    [ "mode", "classFl__Menu__.html#a699c141a15e91b1b9ee3a733981432c2", null ],
    [ "mvalue", "classFl__Menu__.html#a84b5179acdfc38806877c9ac555ccc4c", null ],
    [ "picked", "classFl__Menu__.html#a0a528db63b4eaa0edda217787a0c9d5a", null ],
    [ "remove", "classFl__Menu__.html#a996d42cd9e182b2e8a614b0d167e894d", null ],
    [ "replace", "classFl__Menu__.html#a04bfa23cd703851f5572183d169033da", null ],
    [ "shortcut", "classFl__Menu__.html#aa8080134808c3785579bde1c4ff57f62", null ],
    [ "size", "classFl__Menu__.html#a56d014765ec71a15ecca109348180f45", null ],
    [ "size", "classFl__Menu__.html#aa463d62547f2f3d60629d2fb0fd400a9", null ],
    [ "test_shortcut", "classFl__Menu__.html#a49fcec9173f32fe6d4679e1add17ef35", null ],
    [ "text", "classFl__Menu__.html#a65447e98577519c36eb6b3561192e7cd", null ],
    [ "text", "classFl__Menu__.html#a71c781fc0bce10478be9351548d0f10a", null ],
    [ "textcolor", "classFl__Menu__.html#add340d9589169fdbe087bf2fcab90d08", null ],
    [ "textcolor", "classFl__Menu__.html#a997e2f638e96b61f30345b9648fcb6ad", null ],
    [ "textfont", "classFl__Menu__.html#a5a4ff7e9d8784332e04dbb88012f3899", null ],
    [ "textfont", "classFl__Menu__.html#aed10c2cc1c8ed6e41762f40c7f08f650", null ],
    [ "textsize", "classFl__Menu__.html#a6c275dfa1108c9c12ea9759a8bb0f551", null ],
    [ "textsize", "classFl__Menu__.html#a70bd261129258897b5eae57077c4ae85", null ],
    [ "value", "classFl__Menu__.html#a40abf9e10bb55f479effbf3a15a778bf", null ],
    [ "value", "classFl__Menu__.html#a50e0e4239f0cd1d409f7a4c02229ef8d", null ],
    [ "value", "classFl__Menu__.html#a7ec459b9824a7f7e3794c92aa18a4dc8", null ],
    [ "alloc", "classFl__Menu__.html#af32488db508b716f0598dc10494aedf2", null ],
    [ "down_box_", "classFl__Menu__.html#a08eec75fc83363fdea39ef1325b6a941", null ],
    [ "textcolor_", "classFl__Menu__.html#ac54fa9320419914ba95e8576014c8e61", null ],
    [ "textfont_", "classFl__Menu__.html#a78e644caf7add45ad835b9820ad66b9d", null ],
    [ "textsize_", "classFl__Menu__.html#a2ac8bee9ccc644733cb4724892680cc2", null ]
];

==> fltk-docs-1.3.4-1-aarch64.pkg.tar.xz: usr/share/doc/fltk/classFl__Menu__.js <==
var classFl__Menu__ =
[
    [ "Fl_Menu_", "classFl__Menu__.html#aacd1de7901a51192b721bb5b7263f762", null ],
    [ "~Fl_Menu_", "classFl__Menu__.html#a4bbee6469b549cae405dae0f647397a3", null ],
    [ "add", "classFl__Menu__.html#ac380c9009765c4288577f01af9a3e4d5", null ],
    [ "add", "classFl__Menu__.html#aa4522277d81f2b6318136ea0020c20d4", null ],
    [ "add", "classFl__Menu__.html#a67b693829c184e98bb9b9cd0eb165a84", null ],
    [ "clear", "classFl__Menu__.html#a0e96567cab88c6b60e0be3dfcda00a99", null ],
    [ "clear_submenu", "classFl__Menu__.html#a9f5d44f76658dc88431e4c5e53a2aaf5", null ],
    [ "copy", "classFl__Menu__.html#a946f4bc95480ea9fe8113ddf6ae67c0d", null ],
    [ "down_box", "classFl__Menu__.html#acfe28156d719278f403fc3bb23502edc", null ],
    [ "down_box", "classFl__Menu__.html#a76c3794608213f1bb1d01f677a88d239", null ],
    [ "down_color", "classFl__Menu__.html#a0fe4aafeec44d426b3a5cc85f0530be3", null ],
    [ "down_color", "classFl__Menu__.html#a17fa5c0577f05569787d6cd469d0d900", null ],
    [ "find_index", "classFl__Menu__.html#aacc5f170e9c8961b7d3916c2849a1636", null ],
    [ "find_index", "classFl__Menu__.html#aeb76e76ebd2019937b86ea29d01ce734", null ],
    [ "find_index", "classFl__Menu__.html#ab92deedce3914c45d762937e939976a9", null ],
    [ "find_item", "classFl__Menu__.html#a83e66d9b948df288e9f36d812093e922", null ],
    [ "find_item", "classFl__Menu__.html#adc7c427163be5120501b6d54c259a251", null ],
    [ "global", "classFl__Menu__.html#aea0c7fce644de6b8703a6d8fff1941c0", null ],
    [ "insert", "classFl__Menu__.html#a4a6d21b279e679a93b13eee2534f9f64", null ],
    [ "insert", "classFl__Menu__.html#a799f709782364cd096b07fa6f14382b5", null ],
    [ "item_pathname", "classFl__Menu__.html#abe4ba98d1af637c1e452df648c19502c", null ],
    [ "item_pathname_", "classFl__Menu__.html#a0d1d43166f708cde021bf54825b62eb1", null ],
    [ "menu", "classFl__Menu__.html#a3aff19a70405238f46a1d79bb540e1e7", null ],
    [ "menu", "classFl__Menu__.html#aa0708c71ee8422bf3e92b8fa471eda9f", null ],
    [ "mode", "classFl__Menu__.html#a1093ab1105fc5ecbaf9ae702c21ecf36", null ],
    [ "mode", "classFl__Menu__.html#ac9a46c57a25c5912d77b89425dece498", null ],
    [ "mvalue", "classFl__Menu__.html#a08e0e360e4058971fc3b674dcfdf6180", null ],
    [ "picked", "classFl__Menu__.html#a0a528db63b4eaa0edda217787a0c9d5a", null ],
    [ "remove", "classFl__Menu__.html#a996d42cd9e182b2e8a614b0d167e894d", null ],
    [ "replace", "classFl__Menu__.html#a04bfa23cd703851f5572183d169033da", null ],
    [ "setonly", "classFl__Menu__.html#a47ee79c17b2cfab6eca1165b653f338f", null ],
    [ "shortcut", "classFl__Menu__.html#aa8080134808c3785579bde1c4ff57f62", null ],
    [ "size", "classFl__Menu__.html#a2e1f09f0534831c647173d160e641e00", null ],
    [ "size", "classFl__Menu__.html#aa463d62547f2f3d60629d2fb0fd400a9", null ],
    [ "test_shortcut", "classFl__Menu__.html#a49fcec9173f32fe6d4679e1add17ef35", null ],
    [ "text", "classFl__Menu__.html#afede557153e18bcfba048a06b4a72262", null ],
    [ "text", "classFl__Menu__.html#a16a2d3766e049fdb99f5ea40facffdee", null ],
    [ "textcolor", "classFl__Menu__.html#afdb4b716e812207137653e78828f338c", null ],
    [ "textcolor", "classFl__Menu__.html#a997e2f638e96b61f30345b9648fcb6ad", null ],
    [ "textfont", "classFl__Menu__.html#a5d98a5c6f63c7d9ecc9d63983aa86b61", null ],
    [ "textfont", "classFl__Menu__.html#aed10c2cc1c8ed6e41762f40c7f08f650", null ],
    [ "textsize", "classFl__Menu__.html#a8d477999ef322d73aaf9da709278e3c0", null ],
    [ "textsize", "classFl__Menu__.html#a70bd261129258897b5eae57077c4ae85", null ],
    [ "value", "classFl__Menu__.html#a760812b12dc473781b132e6a0a7c33e3", null ],
    [ "value", "classFl__Menu__.html#a50e0e4239f0cd1d409f7a4c02229ef8d", null ],
    [ "value", "classFl__Menu__.html#a7ec459b9824a7f7e3794c92aa18a4dc8", null ],
    [ "alloc", "classFl__Menu__.html#af32488db508b716f0598dc10494aedf2", null ],
    [ "down_box_", "classFl__Menu__.html#a08eec75fc83363fdea39ef1325b6a941", null ],
    [ "textcolor_", "classFl__Menu__.html#ac54fa9320419914ba95e8576014c8e61", null ],
    [ "textfont_", "classFl__Menu__.html#a78e644caf7add45ad835b9820ad66b9d", null ],
    [ "textsize_", "classFl__Menu__.html#a2ac8bee9ccc644733cb4724892680cc2", null ]
];
